@@ -1,3 +1,6 @@
 def SayHello():
     print("Hello from MyPyPiPackage")
     return
+
+def add(x,y):
+    return x+y
\ No newline at end of file
